@@ -20,9 +20,10 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
+#include <Lum/Def/AppInfo.h>
+
 #include <Lum/Model/Action.h>
 
-#include <Lum/AppInfo.h>
 #include <Lum/Object.h>
 
 namespace Lum {
@@ -33,7 +34,7 @@ namespace Lum {
   class LUMAPI About : public Component
   {
   private:
-    AppInfo info;
+    Def::AppInfo info;
 
     Model::ActionRef illuminationAction;
 
@@ -41,7 +42,7 @@ namespace Lum {
     About();
     virtual ~About();
 
-    void SetAppInfo(const AppInfo& info);
+    void SetAppInfo(const Def::AppInfo& info);
 
     void CalcSize();
   };
