@@ -22,7 +22,7 @@
 
 #include <Lum/Private/ImportExport.h>
 
-#include <Lum/AppInfo.h>
+#include <Lum/Def/AppInfo.h>
 
 #include <Lum/Dlg/ActionDialog.h>
 
@@ -33,7 +33,7 @@ namespace Lum {
     class LUMAPI About : public ActionDialog
     {
     private:
-      Lum::AppInfo info;
+      Def::AppInfo info;
 
     public:
       About();
@@ -42,10 +42,10 @@ namespace Lum {
       Lum::Object* GetContent();
       void GetActions(std::vector<Lum::Dlg::ActionInfo>& actions);
 
-      void SetAppInfo(const AppInfo& info);
+      void SetAppInfo(const Def::AppInfo& info);
 
-      static void Show(Dialog* parent, const AppInfo& info);
-      static void Show(OS::Window* parent, const AppInfo& info);
+      static void Show(Dialog* parent, const Def::AppInfo& info);
+      static void Show(OS::Window* parent, const Def::AppInfo& info);
     };
   }
 }
