@@ -48,6 +48,9 @@ namespace Lum {
     void Draw(int x, int y, size_t w, size_t h);
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
+
+    static FuelGauge* Create(bool horizontalFlex=false, bool verticalFlex=false);
+    static FuelGauge* Create(Base::Model* model, bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
