@@ -61,18 +61,22 @@ namespace Lum {
       {
         assert(!this->IsNull());
 
-        this->value.value++;
+        if (this->maximum-1>=this->value.value) {
+          this->value.value++;
 
-        this->Notify();
+          this->Notify();
+        }
       }
 
       void Dec()
       {
         assert(!this->IsNull());
 
-        this->value.value--;
+        if (this->minimum+1<=this->value.value) {
+          this->value.value--;
 
-        this->Notify();
+          this->Notify();
+        }
       }
 
       void Add(N x)
