@@ -27,8 +27,6 @@
 #include <Lum/Object.h>
 #include <Lum/Header.h>
 #include <Lum/KineticScroller.h>
-#include <Lum/Panel.h>
-#include <Lum/Scroller.h>
 #include <Lum/TableView.h>
 
 namespace Lum {
