@@ -399,9 +399,17 @@ namespace Lum {
       }
       dirList->On();
 
+
+      // Later we should only avoid selection if the path is a file,
+      // the file does not exist and choosing non-existing files is allowed
+      if (GetOpenedAction()->IsFinished() &&
+          !path->Get().IsEmpty() &&
+          !path->Get().GetBaseName().empty()) {
+        return;
+      }
+
       // TODO: If path is not empty, try to select it in existing list.
-      if (dirList->GetRows()>0 &&
-          path->Get().IsEmpty()) {
+      if (dirList->GetRows()>0) {
         dynamic_cast<Model::SingleLineSelection*>(table->GetTableView()->GetSelection())->SelectLine(1);
       }
     }
@@ -584,34 +592,42 @@ namespace Lum {
       if (model==showHidden) {
         Load();
       }
-      else if (model==okAction  && okAction->IsFinished()) {
+      else if (model==okAction  &&
+               okAction->IsFinished()) {
         OnOk();
       }
-      else if (model==GetClosedAction() && GetClosedAction()->IsFinished()) {
+      else if (model==GetClosedAction() &&
+               GetClosedAction()->IsFinished()) {
         result=false;
         Exit();
       }
-      else if (model==GetOpenedAction() && GetOpenedAction()->IsFinished()) {
+      else if (model==GetOpenedAction() &&
+               GetOpenedAction()->IsFinished()) {
         path->On();
         showHidden->On(false);
         SetFocus(table->GetTableView());
       }
-      else if (model==reloadAction && reloadAction->IsFinished()) {
+      else if (model==reloadAction &&
+               reloadAction->IsFinished()) {
         Load();
       }
-      else if (model==parentAction && parentAction->IsFinished()) {
+      else if (model==parentAction &&
+               parentAction->IsFinished()) {
         GotoParent();
       }
-      else if (model==fullAction && fullAction->IsFinished()) {
+      else if (model==fullAction &&
+               fullAction->IsFinished()) {
         HandleChange();
       }
       else if (model==selection) {
         OnSelectionChange();
       }
-      else if (model==doubleClickAction && doubleClickAction->IsFinished()) {
+      else if (model==doubleClickAction &&
+               doubleClickAction->IsFinished()) {
         OnDoubleClick();
       }
-      else if (model==locationsAction && locationsAction->IsFinished()) {
+      else if (model==locationsAction &&
+               locationsAction->IsFinished()) {
         Locations *popup;
 
         popup=new Locations();
@@ -632,7 +648,9 @@ namespace Lum {
 
         delete popup;
        }
-      else if (model==filter && dirList.Valid() && options.Valid()) {
+      else if (model==filter &&
+               dirList.Valid() &&
+               options.Valid()) {
         dirList->SetFilter(options->filters[filter->Get()-1]);
         if (table!=NULL) {
           Load();
