@@ -898,8 +898,7 @@ namespace Lum {
     if (image.Valid()) {
       // Left align image
       image->Draw(draw,
-                   x1,y+(height-image->GetHeight()) / 2,
-                   image->GetWidth(),image->GetHeight());
+                   x1,y+(height-image->GetHeight()) / 2);
     }
   }
 
@@ -928,8 +927,7 @@ namespace Lum {
     if (subImage.Valid()) {
       // Left align sub image
       subImage->Draw(draw,
-                     x4,y+(height-subImage->GetHeight()) / 2,
-                     subImage->GetWidth(),subImage->GetHeight());
+                     x4,y+(height-subImage->GetHeight()) / 2);
     }
   }
 
@@ -1085,9 +1083,9 @@ namespace Lum {
     OS::ImageRef divider=OS::display->GetImage(OS::Display::menuDividerImageIndex);
     OS::DrawInfo *draw=GetDrawInfo();
 
-    divider->Draw(draw,
-                  this->x,this->y+(height-divider->GetHeight())/2,
-                  this->width,divider->GetHeight());
+    divider->DrawStretched(draw,
+                           this->x,this->y+(height-divider->GetHeight())/2,
+                           this->width,divider->GetHeight());
   }
 
   /* ---------- Sub menu stuff ------------------*/
@@ -1793,8 +1791,8 @@ namespace Lum {
       y=window->GetY();
     }
 
-    x=Base::RoundRange(x,0,OS::display->GetScreenWidth()-1-window->GetWidth());
-    y=Base::RoundRange(y,0,OS::display->GetScreenHeight()-1-window->GetHeight());
+    x=Base::RoundRange(x,0,(int)(OS::display->GetScreenWidth()-1-window->GetWidth()));
+    y=Base::RoundRange(y,0,(int)(OS::display->GetScreenHeight()-1-window->GetHeight()));
 
     window->SetPos(x,y);
     window->SetPosition(OS::Window::positionManual,OS::Window::positionManual);
