@@ -129,7 +129,10 @@ namespace Lum {
               Model::ActionRef action=dynamic_cast<Lum::Model::Action*>(model);
 
               if (actions.find(action)!=actions.end()) {
-                if (action->IsEnabled() && action->IsFinished() && IsOpen()) {
+                if (action->IsEnabled() &&
+                    action->IsFinished() &&
+                    IsOpen() &&
+                    IsShown()) {
                   Hide();
                   return;
                 }
