@@ -24,7 +24,6 @@ namespace Lum {
     namespace Manager {
 
       NetworkManager::NetworkManager()
-      : stateChangedAction(new Model::Action())
       {
         // no code
       }
@@ -33,11 +32,6 @@ namespace Lum {
       {
         // no code
       }
-
-      Model::Action* NetworkManager::GetStateChangedAction() const
-      {
-        return stateChangedAction;
-      }
     }
   }
 }
