@@ -44,6 +44,7 @@ namespace Lum {
     assert(!inited);
 
     this->format=format;
+    dynamic_cast<TimeView*>(control)->SetFormat(format);
   }
 
   void TimeSelect::OpenPopup()
@@ -70,7 +71,8 @@ namespace Lum {
 
   void TimeSelect::Resync(Base::Model* model, const Base::ResyncMsg& msg)
   {
-    if (model==popupAction && popupAction->IsFinished()) {
+    if (model==popupAction &&
+        popupAction->IsFinished()) {
       OpenPopup();
     }
 
