@@ -517,22 +517,14 @@ namespace Lum {
 
   void Window::ReinitWindow()
   {
-    if (IsShown()) {
-      main->Hide();
-    }
+    main->CalcSize();
 
-    CalcSize();
     window->Resize(main->GetOWidth(),main->GetOHeight());
 
-    if (IsShown()) {
-      main->Move(0,0);
-      main->Layout();
-      main->DrawBackground(window->GetDrawInfo(),0,0,window->GetWidth(),window->GetHeight());
-      main->Draw(0,0,window->GetWidth(),window->GetHeight());
-      keyHandler.SetFocusFirst();
-    }
-    else {
-      main->Resize(window->GetWidth(),window->GetHeight());
+    if (IsShown() || IsOpen()) {
+      // This has to be tested
+      window->TriggerResize(main->GetOWidth(),main->GetOHeight());
+      window->TriggerRedraw(0,0,window->GetWidth(),window->GetHeight());
     }
   }
 
